@@ -13,7 +13,7 @@
 # define LIBC_MUSL 4
 #endif
 #ifndef TARGET_DEFAULT_ISA_SPEC
-# define TARGET_DEFAULT_ISA_SPEC ISA_SPEC_CLASS_2P2
+# define TARGET_DEFAULT_ISA_SPEC ISA_SPEC_CLASS_20191213
 #endif
 #ifndef TARGET_RISCV_ATTRIBUTE
 # define TARGET_RISCV_ATTRIBUTE 1
